@@ -33,6 +33,7 @@
 #include "libinput-log.h"
 #include "libinput-plugin-button-debounce.h"
 #include "libinput-plugin.h"
+#include "libinput-private.h"
 #include "libinput-util.h"
 #include "quirks.h"
 #include "timer.h"
@@ -264,6 +265,11 @@ debounce_notify_button(struct plugin_device *device,
 	libinput_plugin_prepend_evdev_frame(device->parent->plugin,
 					    device->device,
 					    frame);
+
+	/* If we used the original frame, reset it to avoid re-sending any
+	 * non-button events that may be present in this frame */
+	if (button_frame == NULL)
+		evdev_frame_reset(frame);
 }
 
 static void
@@ -725,6 +731,9 @@ debounce_plugin_device_added(struct libinput_plugin *libinput_plugin,
 	if (!libinput_device_has_capability(device, LIBINPUT_DEVICE_CAP_POINTER))
 		return;
 
+	if (libinput_device_is_virtual(device))
+		return;
+
 	_unref_(udev_device) *udev_device = libinput_device_get_udev_device(device);
 	if (udev_device) {
 		const char *prop = udev_device_get_property_value(udev_device,
